@@ -6,8 +6,7 @@
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#ifndef KSMTP_LOGINJOB_H
-#define KSMTP_LOGINJOB_H
+#pragma once
 
 #include "ksmtp_export.h"
 
@@ -25,12 +24,6 @@ class KSMTP_EXPORT LoginJob : public Job
     Q_DECLARE_PRIVATE(LoginJob)
 
 public:
-    enum EncryptionMode {
-        Unencrypted,
-        SSLorTLS, ///< Use SSL/TLS encryption
-        STARTTLS ///< Use STARTTLS to upgrade an unencrypted connection to encrypted
-    };
-
     enum AuthMode { UnknownAuth, Plain, Login, CramMD5, DigestMD5, NTLM, GSSAPI, Anonymous, XOAuth2 };
 
     enum LoginError { TokenExpired = KJob::UserDefinedError + 1 };
@@ -44,13 +37,9 @@ public:
     void setPreferedAuthMode(AuthMode mode);
     Q_REQUIRED_RESULT AuthMode usedAuthMode() const;
 
-    void setEncryptionMode(EncryptionMode mode);
-    Q_REQUIRED_RESULT EncryptionMode encryptionMode() const;
-
 protected:
     void doStart() override;
     void handleResponse(const ServerResponse &r) override;
 };
 }
 
-#endif // KSMTP_LOGINJOB_H
